@@ -2,11 +2,11 @@
 #define PZK_H_
 #include <zookeeper/zookeeper.h>
 
-typedef struct {
+typedef struct pzk {
     zhandle_t* handle;
+    void (*destroy) (struct pzk*);
 } pzk_t;
 
 pzk_t* new_pzk(zhandle_t*);
-void destroy_pzk(pzk_t*);
 
 #endif // ifndef PZK_H_
